@@ -1120,7 +1120,7 @@ store_yuv_surface_to_file(FILE *fp,
                 g_dst_file_fourcc == VA_FOURCC_BGRX)) {
         return store_rgb_surface_to_rgb_file(fp, surface_id);
     } else if (g_out_fourcc == VA_FOURCC_RGBP &&
-               g_dst_file_fourcc == VA_FOURCC_RGBP) {
+               g_out_fourcc == VA_FOURCC_BGRP) {
         return store_rgbp_surface_to_rgbp_file(fp, surface_id);
     } else {
         printf("Not supported YUV fourcc for output !!!\n");
@@ -1714,6 +1714,9 @@ parse_fourcc_and_format(char *str, uint32_t *fourcc, uint32_t *format)
     } else if (!strcmp(str, "RGBP")) {
         tfourcc = VA_FOURCC_RGBP;
         tformat = VA_RT_FORMAT_RGBP;
+    } else if (!strcmp(str, "BGRP")) {
+        tfourcc = VA_FOURCC_BGRP;
+        tformat = VA_RT_FORMAT_RGBP;
     } else {
         printf("Not supported format: %s! Currently only support following format: %s\n",
                str, "YV12, I420, NV12, YUY2(YUYV), UYVY, AYUV, P010, I010, RGBA, RGBX, BGRA, "
